@@ -16,7 +16,7 @@ from naas_drivers.tools.bubble import Bubble
 from naas_drivers.tools.healthcheck import Healthcheck
 from naas_drivers.tools.ifttt import Ifttt
 from naas_drivers.tools.integromat import Integromat
-from naas_drivers.tools.zappier import Zappier
+from naas_drivers.tools.zapier import Zapier
 from naas_drivers.tools.email import Email
 from naas_drivers.tools.bobapp import Bobapp
 from naas_drivers.tools.airtable import Airtable
@@ -37,7 +37,7 @@ from naas_drivers.tools.huggingface import Huggingface
 import requests
 import os
 
-__version__ = "0.70.9"
+__version__ = "0.70.11"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -70,7 +70,7 @@ email = Email()
 healthcheck = Healthcheck()
 ifttt = Ifttt()
 integromat = Integromat()
-zappier = Zappier()
+zapier = Zapier()
 streamlit = Streamlit()
 
 # InOut drivers
